import React, { useContext } from 'react'
import { mount } from '@cypress/react'
import { apiContext, APIProvider, useAPI } from './SwaggerApi';
import { SnackbarProvider } from 'notistack';

function AppHarness({ children }) {
  return (
    <SnackbarProvider preventDuplicate maxSnack="5">
      {children}
    </SnackbarProvider>
  )
}

function mountIntoHarness(children) {
  mount(<AppHarness>{children}</AppHarness>);
}

function checkAPIDisplayed() {
  cy.get('#api').contains('CE deployment tool API');
}

function DisplayAPISpecification({api}) {
  return <pre id="api">{JSON.stringify(api, null, 2)}</pre>;
}

context("API", () => {

  describe("useAPI", () => {
    it('creates the SwaggerClient', () => {
      const Glue = () => {
        const [api] = useAPI();
        return <DisplayAPISpecification api={api} />;
      }
      mountIntoHarness(<Glue />)
      checkAPIDisplayed();
    })
  })

  describe("APIProvider", () => {
    it('makes the API available via context', () => {
      const Glue = () => {
        const api = useContext(apiContext);
        return <DisplayAPISpecification api={api} />
      }
      mountIntoHarness(
        <APIProvider>
          <Glue />
        </APIProvider>
      );
      checkAPIDisplayed();
    })
  })

});