import React, { useState, useEffect } from "react";
import {
    Container,
    Paper,
    Grid,
    Hidden,
    Tabs,
    Tab,
    Typography
} from '@material-ui/core';
import { RootContainer } from "../../components/common/Container/RootContainer";
import { HostList } from '../../components/host/HostList';
import { HostTable } from '../../components/host/HostTable';
import { useCSEntrySearch } from "../../api/SwaggerApi";
import { useGlobalAppBar } from '../../components/navigation/GlobalAppBar/GlobalAppBar';
import { makeStyles } from '@material-ui/core/styles';
import { initRequestParams, transformHostQuery } from "../../components/common/Helper";
import { SearchBar } from "../../components/common/SearchBar/SearchBar";

const useStyles = makeStyles((theme) => ({
    root: {
        marginBottom: theme.spacing(2),
    },
}));

export function HostListView() {
    useGlobalAppBar("IOC hosts");

    const [hosts, getHosts, /*reset*/, loading] = useCSEntrySearch();
    const [hostFilter, setHostFilter] = useState("ALL");
    const [selectedTab, setSelectedTab] = useState(0);
    const [query, setQuery] = useState("");
    const classes = useStyles();

    const handleTabChange = (event, tab) => {
        setSelectedTab(tab);
    
        if (tab === 0) {
            setHostFilter("ALL");
        }
        else if (tab === 1) {
            setHostFilter("IOCS_DEPLOYED");
        }
        else if (tab === 2) {
            setHostFilter("NO_IOCS");
        }
        else if (tab === 3) {
            setHostFilter("OWN");
        }
      };

    const [lazyParams, setLazyParams] = useState({
        first: 0,
        rows: 20,
        page: 0
    });

    const [columnSort, setColumnSort] = useState({
        sortField: null,
        sortOrder: null
    });

    const rowsPerPage = [20, 50];

    useEffect(() => {
        let requestParams = initRequestParams(lazyParams, transformHostQuery(query), columnSort);
        requestParams.filter = hostFilter;

        getHosts(requestParams);
    }, [getHosts, lazyParams, query, columnSort, hostFilter])

    const content = (
        <>
            <SearchBar search={setQuery} loading={loading}>
                <Hidden smUp>
                    <HostList hosts={hosts.hostList} />
                </Hidden>
                <Hidden xsDown>
                    <HostTable hosts={hosts.hostList} loading={loading}
                        totalCount={hosts.totalCount} lazyParams={lazyParams} setLazyParams={setLazyParams} columnSort={columnSort} setColumnSort={setColumnSort}
                        rowsPerPage={rowsPerPage} />
                </Hidden>
            </SearchBar>
        </>
    );

    return (
        <RootContainer>
            <Paper className={classes.root}>
                <Grid container spacing={1} justify="flex-end">
                    <Container>
                        <Grid container spacing={1} justify="space-between">
                            <Grid item xs={8}>
                                <Tabs
                                    value={selectedTab}
                                    onChange={handleTabChange}
                                    indicatorColor="primary"
                                    textColor="primary">
                                    <Tab label={<Typography variant="h5">All</Typography>} />
                                    <Tab label={<Typography variant="h5">Only hosts with IOCs</Typography>} />
                                    <Tab label={<Typography variant="h5">Only hosts without IOCs</Typography>} />
                                    <Tab label={<Typography variant="h5">Only my IOC-hosts</Typography>} />
                                </Tabs>
                            </Grid>
                        </Grid>
                    </Container>
                    <Grid item xs={12} md={12}>
                        {content}
                    </Grid>
                </Grid>
            </Paper>
        </RootContainer>
    );
}